==> boto_session_manager-0.0.4.tar.gz: boto_session_manager-0.0.4/boto_session_manager/services.py <==
# -*- coding: utf-8 -*-


class AwsServiceEnum:
    AccessAnalyzer = "accessanalyzer"
    Account = "account"
    ACM = "acm"
    ACMPCA = "acm-pca"
    AlexaForBusiness = "alexaforbusiness"
    PrometheusService = "amp"
    Amplify = "amplify"
    AmplifyBackend = "amplifybackend"
    AmplifyUIBuilder = "amplifyuibuilder"
    APIGateway = "apigateway"
    ApiGatewayManagementApi = "apigatewaymanagementapi"
    ApiGatewayV2 = "apigatewayv2"
    AppConfig = "appconfig"
    AppConfigData = "appconfigdata"
    Appflow = "appflow"
    AppIntegrationsService = "appintegrations"
    ApplicationAutoScaling = "application-autoscaling"
    ApplicationInsights = "application-insights"
    ApplicationCostProfiler = "applicationcostprofiler"
    AppMesh = "appmesh"
    AppRunner = "apprunner"
    AppStream = "appstream"
    AppSync = "appsync"
    Athena = "athena"
    AuditManager = "auditmanager"
    AutoScaling = "autoscaling"
    AutoScalingPlans = "autoscaling-plans"
    Backup = "backup"
    BackupGateway = "backup-gateway"
    Batch = "batch"
    BillingConductor = "billingconductor"
    Braket = "braket"
    Budgets = "budgets"
    CostExplorer = "ce"
    Chime = "chime"
    ChimeSDKIdentity = "chime-sdk-identity"
    ChimeSDKMeetings = "chime-sdk-meetings"
    ChimeSDKMessaging = "chime-sdk-messaging"
    Cloud9 = "cloud9"
    CloudControlApi = "cloudcontrol"
    CloudDirectory = "clouddirectory"
    CloudFormation = "cloudformation"
    CloudFront = "cloudfront"
    CloudHSM = "cloudhsm"
    CloudHSMV2 = "cloudhsmv2"
    CloudSearch = "cloudsearch"
    CloudSearchDomain = "cloudsearchdomain"
    CloudTrail = "cloudtrail"
    CloudWatch = "cloudwatch"
    CodeArtifact = "codeartifact"
    CodeBuild = "codebuild"
    CodeCommit = "codecommit"
    CodeDeploy = "codedeploy"
    CodeGuruReviewer = "codeguru-reviewer"
    CodeGuruProfiler = "codeguruprofiler"
    CodePipeline = "codepipeline"
    CodeStar = "codestar"
    CodeStarconnections = "codestar-connections"
    CodeStarNotifications = "codestar-notifications"
    CognitoIdentity = "cognito-identity"
    CognitoIdentityProvider = "cognito-idp"
    CognitoSync = "cognito-sync"
    Comprehend = "comprehend"
    ComprehendMedical = "comprehendmedical"
    ComputeOptimizer = "compute-optimizer"
    ConfigService = "config"
    Connect = "connect"
    ConnectContactLens = "connect-contact-lens"
    ConnectParticipant = "connectparticipant"
    CostandUsageReportService = "cur"
    CustomerProfiles = "customer-profiles"
    GlueDataBrew = "databrew"
    DataExchange = "dataexchange"
    DataPipeline = "datapipeline"
    DataSync = "datasync"
    DAX = "dax"
    Detective = "detective"
    DeviceFarm = "devicefarm"
    DevOpsGuru = "devops-guru"
    DirectConnect = "directconnect"
    ApplicationDiscoveryService = "discovery"
    DLM = "dlm"
    DatabaseMigrationService = "dms"
    DocDB = "docdb"
    drs = "drs"
    DirectoryService = "ds"
    DynamoDB = "dynamodb"
    DynamoDBStreams = "dynamodbstreams"
    EBS = "ebs"
    EC2 = "ec2"
    EC2InstanceConnect = "ec2-instance-connect"
    ECR = "ecr"
    ECRPublic = "ecr-public"
    ECS = "ecs"
    EFS = "efs"
    EKS = "eks"
    ElasticInference = "elastic-inference"
    ElastiCache = "elasticache"
    ElasticBeanstalk = "elasticbeanstalk"
    ElasticTranscoder = "elastictranscoder"
    ElasticLoadBalancing = "elb"
    ElasticLoadBalancingv2 = "elbv2"
    EMR = "emr"
    EMRContainers = "emr-containers"
    ElasticsearchService = "es"
    EventBridge = "events"
    CloudWatchEvidently = "evidently"
    finspace = "finspace"
    FinSpaceData = "finspace-data"
    Firehose = "firehose"
    FIS = "fis"
    FMS = "fms"
    ForecastService = "forecast"
    ForecastQueryService = "forecastquery"
    FraudDetector = "frauddetector"
    FSx = "fsx"
    GameLift = "gamelift"
    GameSparks = "gamesparks"
    Glacier = "glacier"
    GlobalAccelerator = "globalaccelerator"
    Glue = "glue"
    ManagedGrafana = "grafana"
    Greengrass = "greengrass"
    GreengrassV2 = "greengrassv2"
    GroundStation = "groundstation"
    GuardDuty = "guardduty"
    Health = "health"
    HealthLake = "healthlake"
    Honeycode = "honeycode"
    IAM = "iam"
    IdentityStore = "identitystore"
    imagebuilder = "imagebuilder"
    ImportExport = "importexport"
    Inspector = "inspector"
    Inspector2 = "inspector2"
    IoT = "iot"
    IoTDataPlane = "iot-data"
    IoTJobsDataPlane = "iot-jobs-data"
    IoT1ClickDevicesService = "iot1click-devices"
    IoT1ClickProjects = "iot1click-projects"
    IoTAnalytics = "iotanalytics"
    IoTDeviceAdvisor = "iotdeviceadvisor"
    IoTEvents = "iotevents"
    IoTEventsData = "iotevents-data"
    IoTFleetHub = "iotfleethub"
    IoTSecureTunneling = "iotsecuretunneling"
    IoTSiteWise = "iotsitewise"
    IoTThingsGraph = "iotthingsgraph"
    IoTTwinMaker = "iottwinmaker"
    IoTWireless = "iotwireless"
    IVS = "ivs"
    Kafka = "kafka"
    KafkaConnect = "kafkaconnect"
    kendra = "kendra"
    Keyspaces = "keyspaces"
    Kinesis = "kinesis"
    KinesisVideoArchivedMedia = "kinesis-video-archived-media"
    KinesisVideoMedia = "kinesis-video-media"
    KinesisVideoSignalingChannels = "kinesis-video-signaling"
    KinesisAnalytics = "kinesisanalytics"
    KinesisAnalyticsV2 = "kinesisanalyticsv2"
    KinesisVideo = "kinesisvideo"
    KMS = "kms"
    LakeFormation = "lakeformation"
    Lambda = "lambda"
    LexModelBuildingService = "lex-models"
    LexRuntimeService = "lex-runtime"
    LexModelsV2 = "lexv2-models"
    LexRuntimeV2 = "lexv2-runtime"
    LicenseManager = "license-manager"
    Lightsail = "lightsail"
    LocationService = "location"
    CloudWatchLogs = "logs"
    LookoutEquipment = "lookoutequipment"
    LookoutMetrics = "lookoutmetrics"
    LookoutforVision = "lookoutvision"
    MachineLearning = "machinelearning"
    Macie = "macie"
    Macie2 = "macie2"
    ManagedBlockchain = "managedblockchain"
    MarketplaceCatalog = "marketplace-catalog"
    MarketplaceEntitlementService = "marketplace-entitlement"
    MarketplaceCommerceAnalytics = "marketplacecommerceanalytics"
    MediaConnect = "mediaconnect"
    MediaConvert = "mediaconvert"
    MediaLive = "medialive"
    MediaPackage = "mediapackage"
    MediaPackageVod = "mediapackage-vod"
    MediaStore = "mediastore"
    MediaStoreData = "mediastore-data"
    MediaTailor = "mediatailor"
    MemoryDB = "memorydb"
    MarketplaceMetering = "meteringmarketplace"
    MigrationHub = "mgh"
    mgn = "mgn"
    MigrationHubRefactorSpaces = "migration-hub-refactor-spaces"
    MigrationHubConfig = "migrationhub-config"
    MigrationHubStrategyRecommendations = "migrationhubstrategy"
    Mobile = "mobile"
    MQ = "mq"
    MTurk = "mturk"
    MWAA = "mwaa"
    Neptune = "neptune"
    NetworkFirewall = "network-firewall"
    NetworkManager = "networkmanager"
    NimbleStudio = "nimble"
    OpenSearchService = "opensearch"
    OpsWorks = "opsworks"
    OpsWorksCM = "opsworkscm"
    Organizations = "organizations"
    Outposts = "outposts"
    Panorama = "panorama"
    Personalize = "personalize"
    PersonalizeEvents = "personalize-events"
    PersonalizeRuntime = "personalize-runtime"
    PI = "pi"
    Pinpoint = "pinpoint"
    PinpointEmail = "pinpoint-email"
    PinpointSMSVoice = "pinpoint-sms-voice"
    PinpointSMSVoiceV2 = "pinpoint-sms-voice-v2"
    Polly = "polly"
    Pricing = "pricing"
    Proton = "proton"
    QLDB = "qldb"
    QLDBSession = "qldb-session"
    QuickSight = "quicksight"
    RAM = "ram"
    RecycleBin = "rbin"
    RDS = "rds"
    RDSDataService = "rds-data"
    Redshift = "redshift"
    RedshiftDataAPIService = "redshift-data"
    Rekognition = "rekognition"
    ResilienceHub = "resiliencehub"
    ResourceGroups = "resource-groups"
    ResourceGroupsTaggingAPI = "resourcegroupstaggingapi"
    RoboMaker = "robomaker"
    Route53 = "route53"
    Route53RecoveryCluster = "route53-recovery-cluster"
    Route53RecoveryControlConfig = "route53-recovery-control-config"
    Route53RecoveryReadiness = "route53-recovery-readiness"
    Route53Domains = "route53domains"
    Route53Resolver = "route53resolver"
    CloudWatchRUM = "rum"
    S3 = "s3"
    S3Control = "s3control"
    S3Outposts = "s3outposts"
    SageMaker = "sagemaker"
    AugmentedAIRuntime = "sagemaker-a2i-runtime"
    SagemakerEdgeManager = "sagemaker-edge"
    SageMakerFeatureStoreRuntime = "sagemaker-featurestore-runtime"
    SageMakerRuntime = "sagemaker-runtime"
    SavingsPlans = "savingsplans"
    Schemas = "schemas"
    SimpleDB = "sdb"
    SecretsManager = "secretsmanager"
    SecurityHub = "securityhub"
    ServerlessApplicationRepository = "serverlessrepo"
    ServiceQuotas = "service-quotas"
    ServiceCatalog = "servicecatalog"
    AppRegistry = "servicecatalog-appregistry"
    ServiceDiscovery = "servicediscovery"
    SES = "ses"
    SESV2 = "sesv2"
    Shield = "shield"
    signer = "signer"
    SMS = "sms"
    PinpointSMSVoice = "sms-voice"
    SnowDeviceManagement = "snow-device-management"
    Snowball = "snowball"
    SNS = "sns"
    SQS = "sqs"
    SSM = "ssm"
    SSMContacts = "ssm-contacts"
    SSMIncidents = "ssm-incidents"
    SSO = "sso"
    SSOAdmin = "sso-admin"
    SSOOIDC = "sso-oidc"
    SFN = "stepfunctions"
    StorageGateway = "storagegateway"
    STS = "sts"
    Support = "support"
    SWF = "swf"
    Synthetics = "synthetics"
    Textract = "textract"
    TimestreamQuery = "timestream-query"
    TimestreamWrite = "timestream-write"
    TranscribeService = "transcribe"
    Transfer = "transfer"
    Translate = "translate"
    VoiceID = "voice-id"
    WAF = "waf"
    WAFRegional = "waf-regional"
    WAFV2 = "wafv2"
    WellArchitected = "wellarchitected"
    ConnectWisdomService = "wisdom"
    WorkDocs = "workdocs"
    WorkLink = "worklink"
    WorkMail = "workmail"
    WorkMailMessageFlow = "workmailmessageflow"
    WorkSpaces = "workspaces"
    WorkSpacesWeb = "workspaces-web"
    XRay = "xray"

==> boto_session_manager-1.3.2.tar.gz: boto_session_manager-1.3.2/boto_session_manager/services.py <==
# -*- coding: utf-8 -*-


class AwsServiceEnum:
    AccessAnalyzer = "accessanalyzer"
    Account = "account"
    ACM = "acm"
    ACMPCA = "acm-pca"
    AlexaForBusiness = "alexaforbusiness"
    PrometheusService = "amp"
    Amplify = "amplify"
    AmplifyBackend = "amplifybackend"
    AmplifyUIBuilder = "amplifyuibuilder"
    APIGateway = "apigateway"
    ApiGatewayManagementApi = "apigatewaymanagementapi"
    ApiGatewayV2 = "apigatewayv2"
    AppConfig = "appconfig"
    AppConfigData = "appconfigdata"
    Appflow = "appflow"
    AppIntegrationsService = "appintegrations"
    ApplicationAutoScaling = "application-autoscaling"
    ApplicationInsights = "application-insights"
    ApplicationCostProfiler = "applicationcostprofiler"
    AppMesh = "appmesh"
    AppRunner = "apprunner"
    AppStream = "appstream"
    AppSync = "appsync"
    ARCZonalShift = "arc-zonal-shift"
    Athena = "athena"
    AuditManager = "auditmanager"
    AutoScaling = "autoscaling"
    AutoScalingPlans = "autoscaling-plans"
    Backup = "backup"
    BackupGateway = "backup-gateway"
    BackupStorage = "backupstorage"
    Batch = "batch"
    BillingConductor = "billingconductor"
    Braket = "braket"
    Budgets = "budgets"
    CostExplorer = "ce"
    Chime = "chime"
    ChimeSDKIdentity = "chime-sdk-identity"
    ChimeSDKMediaPipelines = "chime-sdk-media-pipelines"
    ChimeSDKMeetings = "chime-sdk-meetings"
    ChimeSDKMessaging = "chime-sdk-messaging"
    ChimeSDKVoice = "chime-sdk-voice"
    Cloud9 = "cloud9"
    CloudControlApi = "cloudcontrol"
    CloudDirectory = "clouddirectory"
    CloudFormation = "cloudformation"
    CloudFront = "cloudfront"
    CloudHSM = "cloudhsm"
    CloudHSMV2 = "cloudhsmv2"
    CloudSearch = "cloudsearch"
    CloudSearchDomain = "cloudsearchdomain"
    CloudTrail = "cloudtrail"
    CloudWatch = "cloudwatch"
    CodeArtifact = "codeartifact"
    CodeBuild = "codebuild"
    CodeCatalyst = "codecatalyst"
    CodeCommit = "codecommit"
    CodeDeploy = "codedeploy"
    CodeGuruReviewer = "codeguru-reviewer"
    CodeGuruProfiler = "codeguruprofiler"
    CodePipeline = "codepipeline"
    CodeStar = "codestar"
    CodeStarconnections = "codestar-connections"
    CodeStarNotifications = "codestar-notifications"
    CognitoIdentity = "cognito-identity"
    CognitoIdentityProvider = "cognito-idp"
    CognitoSync = "cognito-sync"
    Comprehend = "comprehend"
    ComprehendMedical = "comprehendmedical"
    ComputeOptimizer = "compute-optimizer"
    ConfigService = "config"
    Connect = "connect"
    ConnectContactLens = "connect-contact-lens"
    ConnectCampaignService = "connectcampaigns"
    ConnectCases = "connectcases"
    ConnectParticipant = "connectparticipant"
    ControlTower = "controltower"
    CostandUsageReportService = "cur"
    CustomerProfiles = "customer-profiles"
    GlueDataBrew = "databrew"
    DataExchange = "dataexchange"
    DataPipeline = "datapipeline"
    DataSync = "datasync"
    DAX = "dax"
    Detective = "detective"
    DeviceFarm = "devicefarm"
    DevOpsGuru = "devops-guru"
    DirectConnect = "directconnect"
    ApplicationDiscoveryService = "discovery"
    DLM = "dlm"
    DatabaseMigrationService = "dms"
    DocDB = "docdb"
    DocDBElastic = "docdb-elastic"
    drs = "drs"
    DirectoryService = "ds"
    DynamoDB = "dynamodb"
    DynamoDBStreams = "dynamodbstreams"
    EBS = "ebs"
    EC2 = "ec2"
    EC2InstanceConnect = "ec2-instance-connect"
    ECR = "ecr"
    ECRPublic = "ecr-public"
    ECS = "ecs"
    EFS = "efs"
    EKS = "eks"
    ElasticInference = "elastic-inference"
    ElastiCache = "elasticache"
    ElasticBeanstalk = "elasticbeanstalk"
    ElasticTranscoder = "elastictranscoder"
    ElasticLoadBalancing = "elb"
    ElasticLoadBalancingv2 = "elbv2"
    EMR = "emr"
    EMRContainers = "emr-containers"
    EMRServerless = "emr-serverless"
    ElasticsearchService = "es"
    EventBridge = "events"
    CloudWatchEvidently = "evidently"
    finspace = "finspace"
    FinSpaceData = "finspace-data"
    Firehose = "firehose"
    FIS = "fis"
    FMS = "fms"
    ForecastService = "forecast"
    ForecastQueryService = "forecastquery"
    FraudDetector = "frauddetector"
    FSx = "fsx"
    GameLift = "gamelift"
    GameSparks = "gamesparks"
    Glacier = "glacier"
    GlobalAccelerator = "globalaccelerator"
    Glue = "glue"
    ManagedGrafana = "grafana"
    Greengrass = "greengrass"
    GreengrassV2 = "greengrassv2"
    GroundStation = "groundstation"
    GuardDuty = "guardduty"
    Health = "health"
    HealthLake = "healthlake"
    Honeycode = "honeycode"
    IAM = "iam"
    IdentityStore = "identitystore"
    imagebuilder = "imagebuilder"
    ImportExport = "importexport"
    Inspector = "inspector"
    Inspector2 = "inspector2"
    IoT = "iot"
    IoTDataPlane = "iot-data"
    IoTJobsDataPlane = "iot-jobs-data"
    IoTRoboRunner = "iot-roborunner"
    IoT1ClickDevicesService = "iot1click-devices"
    IoT1ClickProjects = "iot1click-projects"
    IoTAnalytics = "iotanalytics"
    IoTDeviceAdvisor = "iotdeviceadvisor"
    IoTEvents = "iotevents"
    IoTEventsData = "iotevents-data"
    IoTFleetHub = "iotfleethub"
    IoTFleetWise = "iotfleetwise"
    IoTSecureTunneling = "iotsecuretunneling"
    IoTSiteWise = "iotsitewise"
    IoTThingsGraph = "iotthingsgraph"
    IoTTwinMaker = "iottwinmaker"
    IoTWireless = "iotwireless"
    IVS = "ivs"
    ivschat = "ivschat"
    Kafka = "kafka"
    KafkaConnect = "kafkaconnect"
    kendra = "kendra"
    Keyspaces = "keyspaces"
    Kinesis = "kinesis"
    KinesisVideoArchivedMedia = "kinesis-video-archived-media"
    KinesisVideoMedia = "kinesis-video-media"
    KinesisVideoSignalingChannels = "kinesis-video-signaling"
    KinesisAnalytics = "kinesisanalytics"
    KinesisAnalyticsV2 = "kinesisanalyticsv2"
    KinesisVideo = "kinesisvideo"
    KMS = "kms"
    LakeFormation = "lakeformation"
    Lambda = "lambda"
    LexModelBuildingService = "lex-models"
    LexRuntimeService = "lex-runtime"
    LexModelsV2 = "lexv2-models"
    LexRuntimeV2 = "lexv2-runtime"
    LicenseManager = "license-manager"
    LicenseManagerUserSubscriptions = "license-manager-user-subscriptions"
    Lightsail = "lightsail"
    LocationService = "location"
    CloudWatchLogs = "logs"
    LookoutEquipment = "lookoutequipment"
    LookoutMetrics = "lookoutmetrics"
    LookoutforVision = "lookoutvision"
    MainframeModernization = "m2"
    MachineLearning = "machinelearning"
    Macie = "macie"
    Macie2 = "macie2"
    ManagedBlockchain = "managedblockchain"
    MarketplaceCatalog = "marketplace-catalog"
    MarketplaceEntitlementService = "marketplace-entitlement"
    MarketplaceCommerceAnalytics = "marketplacecommerceanalytics"
    MediaConnect = "mediaconnect"
    MediaConvert = "mediaconvert"
    MediaLive = "medialive"
    MediaPackage = "mediapackage"
    MediaPackageVod = "mediapackage-vod"
    MediaStore = "mediastore"
    MediaStoreData = "mediastore-data"
    MediaTailor = "mediatailor"
    MemoryDB = "memorydb"
    MarketplaceMetering = "meteringmarketplace"
    MigrationHub = "mgh"
    mgn = "mgn"
    MigrationHubRefactorSpaces = "migration-hub-refactor-spaces"
    MigrationHubConfig = "migrationhub-config"
    MigrationHubOrchestrator = "migrationhuborchestrator"
    MigrationHubStrategyRecommendations = "migrationhubstrategy"
    Mobile = "mobile"
    MQ = "mq"
    MTurk = "mturk"
    MWAA = "mwaa"
    Neptune = "neptune"
    NetworkFirewall = "network-firewall"
    NetworkManager = "networkmanager"
    NimbleStudio = "nimble"
    CloudWatchObservabilityAccessManager = "oam"
    Omics = "omics"
    OpenSearchService = "opensearch"
    OpenSearchServiceServerless = "opensearchserverless"
    OpsWorks = "opsworks"
    OpsWorksCM = "opsworkscm"
    Organizations = "organizations"
    Outposts = "outposts"
    Panorama = "panorama"
    Personalize = "personalize"
    PersonalizeEvents = "personalize-events"
    PersonalizeRuntime = "personalize-runtime"
    PI = "pi"
    Pinpoint = "pinpoint"
    PinpointEmail = "pinpoint-email"
    PinpointSMSVoice = "pinpoint-sms-voice"
    PinpointSMSVoiceV2 = "pinpoint-sms-voice-v2"
    EventBridgePipes = "pipes"
    Polly = "polly"
    Pricing = "pricing"
    Private5G = "privatenetworks"
    Proton = "proton"
    QLDB = "qldb"
    QLDBSession = "qldb-session"
    QuickSight = "quicksight"
    RAM = "ram"
    RecycleBin = "rbin"
    RDS = "rds"
    RDSDataService = "rds-data"
    Redshift = "redshift"
    RedshiftDataAPIService = "redshift-data"
    RedshiftServerless = "redshift-serverless"
    Rekognition = "rekognition"
    ResilienceHub = "resiliencehub"
    ResourceExplorer = "resource-explorer-2"
    ResourceGroups = "resource-groups"
    ResourceGroupsTaggingAPI = "resourcegroupstaggingapi"
    RoboMaker = "robomaker"
    IAMRolesAnywhere = "rolesanywhere"
    Route53 = "route53"
    Route53RecoveryCluster = "route53-recovery-cluster"
    Route53RecoveryControlConfig = "route53-recovery-control-config"
    Route53RecoveryReadiness = "route53-recovery-readiness"
    Route53Domains = "route53domains"
    Route53Resolver = "route53resolver"
    CloudWatchRUM = "rum"
    S3 = "s3"
    S3Control = "s3control"
    S3Outposts = "s3outposts"
    SageMaker = "sagemaker"
    AugmentedAIRuntime = "sagemaker-a2i-runtime"
    SagemakerEdgeManager = "sagemaker-edge"
    SageMakerFeatureStoreRuntime = "sagemaker-featurestore-runtime"
    SageMakergeospatialcapabilities = "sagemaker-geospatial"
    SageMakerRuntime = "sagemaker-runtime"
    SavingsPlans = "savingsplans"
    EventBridgeScheduler = "scheduler"
    Schemas = "schemas"
    SimpleDB = "sdb"
    SecretsManager = "secretsmanager"
    SecurityHub = "securityhub"
    SecurityLake = "securitylake"
    ServerlessApplicationRepository = "serverlessrepo"
    ServiceQuotas = "service-quotas"
    ServiceCatalog = "servicecatalog"
    AppRegistry = "servicecatalog-appregistry"
    ServiceDiscovery = "servicediscovery"
    SES = "ses"
    SESV2 = "sesv2"
    Shield = "shield"
    signer = "signer"
    SimSpaceWeaver = "simspaceweaver"
    SMS = "sms"
    PinpointSMSVoice = "sms-voice"
    SnowDeviceManagement = "snow-device-management"
    Snowball = "snowball"
    SNS = "sns"
    SQS = "sqs"
    SSM = "ssm"
    SSMContacts = "ssm-contacts"
    SSMIncidents = "ssm-incidents"
    SsmSap = "ssm-sap"
    SSO = "sso"
    SSOAdmin = "sso-admin"
    SSOOIDC = "sso-oidc"
    SFN = "stepfunctions"
    StorageGateway = "storagegateway"
    STS = "sts"
    Support = "support"
    SupportApp = "support-app"
    SWF = "swf"
    Synthetics = "synthetics"
    Textract = "textract"
    TimestreamQuery = "timestream-query"
    TimestreamWrite = "timestream-write"
    TranscribeService = "transcribe"
    Transfer = "transfer"
    Translate = "translate"
    VoiceID = "voice-id"
    WAF = "waf"
    WAFRegional = "waf-regional"
    WAFV2 = "wafv2"
    WellArchitected = "wellarchitected"
    ConnectWisdomService = "wisdom"
    WorkDocs = "workdocs"
    WorkLink = "worklink"
    WorkMail = "workmail"
    WorkMailMessageFlow = "workmailmessageflow"
    WorkSpaces = "workspaces"
    WorkSpacesWeb = "workspaces-web"
    XRay = "xray"
